@@ -97,12 +97,17 @@ impl Transport for WasmHost {
         req: Message<'_>,
         _opts: Option<crate::SendOpts>,
     ) -> std::result::Result<Vec<u8>, RpcError> {
-        let res = host_call(
-            &self.target.link_name,
-            &self.target.contract_id,
-            req.method,
-            req.arg.as_ref(),
-        )?;
+        let res = if !self.target.public_key.is_empty() {
+            // actor-to-actor calls use namespace for the actor target identifier
+            host_call("", &self.target.public_key, req.method, req.arg.as_ref())?;
+        } else {
+            host_call(
+                &self.target.link_name,
+                &self.target.contract_id,
+                req.method,
+                req.arg.as_ref(),
+            )?;
+        };
         Ok(res)
     }
 }
